package com.mcwl.web.controller.communityCenter;

import com.mcwl.common.core.controller.BaseController;
import com.mcwl.communityCenter.domain.PublicModelCommentVo;
import com.mcwl.communityCenter.domain.PublishCommission;
import com.mcwl.communityCenter.service.PublishCommissionService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**社群评论
 * @Author：ChenYan
 * @Project：mcwl-ai
 * @Package：com.mcwl.web.controller.communityCenter
 * @Filename：PublishCommissionController
 * @Description TODO
 * @Date：2025/1/17 14:21
 */
@Api(tags = "社群评论")
@RequestMapping("PublishCommission")
@RestController
public class PublishCommissionController extends BaseController {

    @Autowired
    private PublishCommissionService publishCommissionService;


    /**
     * 获取评论
     * @param publishCommission
     * @return
     */
    @ApiOperation(value = "获取评论")
    @GetMapping("/comment/{Id}")
    public List<PublicModelCommentVo>  getComment(@RequestBody PublishCommission publishCommission) {

        return publishCommissionService.getComment(publishCommission);
    }

/**
     * 添加评论
     * @param publishCommission
     * @return
     */
    @ApiOperation(value = "添加评论")
    @PostMapping("/save")
    public ResponseEntity<String> save(@RequestBody PublishCommission publishCommission) {
        publishCommissionService.save(publishCommission);
        return ResponseEntity.ok("评论成功");
    }


    /**
     * 点赞或取消点赞评论
     * @param userId 用户ID
     * @param commentId 评论ID
     * @return 更新后的点赞数
     */
    @ApiOperation(value = "点赞或取消点赞评论")
    @PostMapping("/{commentId}/like")
    public ResponseEntity<Integer> toggleLike(@PathVariable Long commentId, @RequestParam Long userId) {
        int updatedLikes = publishCommissionService.toggleLike(userId, commentId);
        return ResponseEntity.ok(updatedLikes);
    }



    @ApiOperation(value = "删除评论")
    @DeleteMapping("/{id}")
    public ResponseEntity<String> delete(@PathVariable Long id) {
        publishCommissionService.removeById(id);
        return ResponseEntity.ok("删除成功");
    }

}
