package com.mcwl.web.controller.resource;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mcwl.common.annotation.RepeatSubmit;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.resource.domain.ModelProduct;
import com.mcwl.resource.domain.vo.MallProductVo;
import com.mcwl.resource.service.MallProductLikeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 点赞商品
 * @author DaiZibo
 * @date 2025/1/2
 * @apiNote
 */
@Api(tags = "点赞商品")
@RequestMapping("/like")
@RestController
public class MallProductLikeController {

    @Autowired
    private MallProductLikeService mallProductLikeService;

    /**
     * 查询用户点赞作品列表
     * @param mallProductVo
     * @return
     */
    @ApiOperation(value = "查询用户点赞作品列表")
    @PostMapping("/selectByUserLike")
    public AjaxResult selectByUserLike(@RequestBody MallProductVo mallProductVo){

        Page<ModelProduct> mallProductPage = mallProductLikeService.selectByUserLike(mallProductVo);
        return AjaxResult.success(mallProductPage);
    }

    /**
     * 添加/删除点赞商品
     * @param productId
     * @return
     */
    @ApiOperation(value = "添加/删除点赞商品")
    @RepeatSubmit
    @GetMapping("/addLike")
    public AjaxResult addLike(@RequestParam Long productId){

        return mallProductLikeService.addLike(productId);
    }

    /**
     * 查看作品是否点赞
     * @param productId
     * @return
     */
    @ApiOperation(value = "查看作品是否点赞")
    @GetMapping("/selectLike")
    public AjaxResult selectLike(@RequestParam Long productId){
        Boolean aBoolean = mallProductLikeService.selectLike(productId);
        return AjaxResult.success(aBoolean);
    }



}
